# Insert your code here. 
print(" Init zqpy core By ZhouQing")
from pkg import *       # 直接可以调用Class, 因为init里面注册了

class BasePyClass(object):

    def __init__(self, *args, **kwargs):
        Log = LogServiceClass(tag=self.vGetLogTag())
        self.LogD = Log.LogD
        self.LogW = Log.LogW
        self.LogE = Log.LogE

        self.FileService = FileServiceClass()
        self.HttpService = HttpServiceClass()
        self.RegexService = RegexServiceClass()
        self.ThreadService = ThreadServiceClass()
        self.TimeService = TimeServiceClass()
        self.VideoDownloadService = VideoDownloadServiceClass()
        self.LocalizeService = LocallizeServiceClass(path=kwargs.get("LocallizePath", None))
        self.WaitExecutService = WaitExecutServiceClass()

        self.QrCodeService = QrCodeServiceClass()

        self.ToolsService = ToolsServiceClass()

        self.MailService = MailServiceClass()

    ############################################通用方法##########################################
    def GetLocalize(self, key):
        return self.Localize.Get(key)

    ############################################子类可重写##########################################
    def vGetLogTag(self):
        return "BasePyClass"

base = BasePyClass()


import time;
import os;
from TimeService import TimeServiceClass
from FileService import FileServiceClass;

class LogServiceClass(object):
    TimeService = TimeServiceClass()
    FileService = FileServiceClass()

    filePath = "{}{}-Common.log".format("./Log/",TimeService.GetPrintTimeToDay()) 
    tag = ""
    def __init__(self, filePath = None, tag = None):
        if filePath != None:
            self.filePath = filePath
        if tag != None:
            self.tag = tag
        self.FileService.AppendFile(self.filePath, "{}{} {} {}".format("\n", self.TimeService.GetPrintTimeToAll(), self.tag, "- Start \n\n"))
        
    # 打印日志
    def Log(self, content, type=0):
        front = "LogD"
        if type == 0:
            front = "LogD"
        elif type == 1:
            front = "LogW"
        elif type == 2:
            front = "LogE"
        outPrint = "{} {} {}: {}".format(self.TimeService.GetPrintTimeToAll(), self.tag, front, content)
        self.SavePrintToFile(outPrint)
        print(outPrint)

    def LogD(self, content):
        self.Log(content, 0)

    def LogW(self, content):
        self.Log(content, 1)

    def LogE(self, content):
        self.Log(content, 2)

    def SavePrintToFile(self, content):
        if self.filePath:
            self.FileService.AppendFile(self.filePath, content, True)

if __name__ == '__main__':
    LogService = LogServiceClass(tag="ADBServiceClass")
    LogService.LogE(15)
    LogService.LogE(16)
    LogService.LogE(17)
    LogService.LogE(18)


import os, sys
sys.path.append(os.path.dirname(__file__))

from LogService import LogServiceClass
from FileService import FileServiceClass
from HttpService import HttpServiceClass
from RegexService import RegexServiceClass
from ThreadService import ThreadServiceClass
from TimeService import TimeServiceClass
from VideoDownloadService import VideoDownloadServiceClass
from LocallizeService import LocallizeServiceClass

from WaitExecutService import WaitExecutServiceClass
from QrCodeService import QrCodeServiceClass
from ToolsService import ToolsServiceClass

from MailService import MailServiceClass